@@ -8,11 +8,12 @@
 # @author Davide Brunato <brunato@sissa.it>
 #
 from abc import abstractmethod
-from .atomic_types import AtomicTypeABCMeta
-from .helpers import QNAME_PATTERN
+
+from ..helpers import QNAME_PATTERN
+from .atomic_types import AtomicTypeMeta
 
 
-class AbstractQName(metaclass=AtomicTypeABCMeta):
+class AbstractQName(metaclass=AtomicTypeMeta):
     """
     XPath compliant QName, bound with a prefix and a namespace.
 
